@@ -14,12 +14,18 @@
 # You should have received a copy of the GNU General Public License
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
+from typing import Any
 from typing import Optional
 
 import logging
 from datetime import datetime
 
+from gi.repository import Gio
 from gi.repository import GLib
+from gi.repository import GObject
+
 from nbxmpp.structs import LocationData
 
 from gajim.common import app
@@ -34,21 +40,21 @@ log = logging.getLogger('gajim.c.dbus.location')
 
 
 class LocationListener:
-    _instance = None
+    _instance: Optional[LocationListener] = None
 
     @classmethod
-    def get(cls):
+    def get(cls) -> LocationListener:
         if cls._instance is None:
             cls._instance = cls()
         if app.is_installed('GEOCLUE') and not cls._instance._running:
             cls._instance.start()
         return cls._instance
 
-    def __init__(self):
-        self._data = {}
-        self.location_info = {}
-        self.simple = None
-        self._current_location = None
+    def __init__(self) -> None:
+        self._data: dict[str, Any] = {}
+        self.location_info: dict[str, Any] = {}
+        self.simple: Optional[Geoclue.Simple] = None
+        self._current_location: Optional[LocationData] = None
         self._running = False
 
     def _emit(self, info: Optional[LocationData]) -> None:
@@ -59,33 +65,38 @@ class LocationListener:
     def current_location(self) -> Optional[LocationData]:
         return self._current_location
 
-    # Note: do not remove third parameter `param`
-    #       because notify signal expects three parameters
-    def _on_location_update(self, simple, _param=None):
+    def _on_location_update(self, simple: Geoclue.Simple, *args: Any) -> None:
         location = simple.get_location()
-        timestamp = location.get_property("timestamp")[0]
-        lat = location.get_property("latitude")
-        lon = location.get_property("longitude")
-        alt = location.get_property("altitude")
+        timestamp = location.get_property('timestamp')[0]
+        lat = location.get_property('latitude')
+        lon = location.get_property('longitude')
+        alt = location.get_property('altitude')
         # in XEP-0080 it's horizontal accuracy
-        acc = location.get_property("accuracy")
+        acc = location.get_property('accuracy')
 
         # update data with info we just received
         self._data = {'lat': lat, 'lon': lon, 'alt': alt, 'accuracy': acc}
         self._data['timestamp'] = self._timestamp_to_utc(timestamp)
         self._send_location()
 
-    def _on_client_update(self, client, _param=None):
+    def _on_client_update(self,
+                          client: Geoclue.Client,
+                          *args: Any
+                          ) -> None:
         if not client.get_property('active'):
             self._emit(None)
 
-    def _on_simple_ready(self, _obj, result):
+    def _on_simple_ready(self,
+                         _obj: GObject.Object,
+                         result: Gio.AsyncResult
+                         ) -> None:
         try:
             self.simple = Geoclue.Simple.new_finish(result)
         except GLib.Error as error:
-            log.warning("Could not enable geolocation: %s", error.message)
+            log.warning('Could not enable geolocation: %s', error.message)
             self._running = False
         else:
+            assert self.simple is not None
             self.simple.connect('notify::location', self._on_location_update)
             client = self.simple.get_client()
             # Inside the flatpak sandbox client will be None,
@@ -95,18 +106,18 @@ class LocationListener:
 
             self._on_location_update(self.simple)
 
-    def get_data(self):
-        Geoclue.Simple.new("org.gajim.Gajim",
+    def get_data(self) -> None:
+        Geoclue.Simple.new('org.gajim.Gajim',
                            Geoclue.AccuracyLevel.EXACT,
                            None,
                            self._on_simple_ready)
 
-    def start(self):
+    def start(self) -> None:
         self._running = True
         self.location_info = {}
         self.get_data()
 
-    def _send_location(self):
+    def _send_location(self) -> None:
         if self.location_info == self._data:
             return
         if 'timestamp' in self.location_info and 'timestamp' in self._data:
@@ -121,6 +132,6 @@ class LocationListener:
         self._emit(info)
 
     @staticmethod
-    def _timestamp_to_utc(timestamp):
+    def _timestamp_to_utc(timestamp: float) -> str:
         time = datetime.utcfromtimestamp(timestamp)
         return time.strftime('%Y-%m-%dT%H:%MZ')
