@@ -139,11 +139,13 @@ class SignedIn(ApplicationEvent):
     account: str
     conn: 'Client'
 
+
 @dataclass
 class LocationChanged(ApplicationEvent):
     name: str = field(init=False, default='location-changed')
     info: Optional[LocationData]
 
+
 @dataclass
 class MusicTrackChanged(ApplicationEvent):
     name: str = field(init=False, default='music-track-changed')
@@ -175,20 +177,6 @@ class MessageNotSent(ApplicationEvent):
     time: float
 
 
-@dataclass
-class AdHocCommandError(ApplicationEvent):
-    name: str = field(init=False, default='adhoc-command-error')
-    conn: 'Client'
-    error: str
-
-
-@dataclass
-class AdHocCommandActionResponse(ApplicationEvent):
-    name: str = field(init=False, default='adhoc-command-action-response')
-    conn: 'Client'
-    command: Any
-
-
 @dataclass
 class FileProgress(ApplicationEvent):
     name: str = field(init=False, default='file-progress')
