@@ -62,21 +62,23 @@ class GroupChatSettings:
         self._jid = jid
 
     @overload
-    def get(self, setting: StringGroupChatSettings) -> str: ...
+    def get(self, setting: StringGroupChatSettings) -> str: ...  # noqa: E704
     @overload
-    def get(self, setting: BoolGroupChatSettings) -> bool: ...
+    def get(self, setting: BoolGroupChatSettings) -> bool: ...  # noqa: E704
     @overload
-    def get(self, setting: IntGroupChatSettings) -> int: ...
+    def get(self, setting: IntGroupChatSettings) -> int: ...  # noqa: E704
+
     def get(self, setting: Any) -> Any:
         return app.settings.get_group_chat_setting(
             self._account, self._jid, setting)
 
     @overload
-    def set(self, setting: StringGroupChatSettings, value: str) -> None: ...
+    def set(self, setting: StringGroupChatSettings, value: str) -> None: ...  # noqa: E501, E704
     @overload
-    def set(self, setting: BoolGroupChatSettings, value: bool) -> None: ...
+    def set(self, setting: BoolGroupChatSettings, value: bool) -> None: ...  # noqa: E501, E704
     @overload
-    def set(self, setting: IntGroupChatSettings, value: int) -> None: ...
+    def set(self, setting: IntGroupChatSettings, value: int) -> None: ...  # noqa: E501, E704
+
     def set(self, setting: Any, value: Any) -> None:
         app.settings.set_group_chat_setting(
             self._account, self._jid, setting, value)
@@ -361,7 +363,6 @@ class BareContact(CommonContact):
 
         transport_icon = None
         if self.is_gateway:
-            show = None
             disco_info = app.storage.cache.get_last_disco_info(self._jid)
             if disco_info is not None:
                 if disco_info.gateway_type == 'sms':
@@ -374,6 +375,9 @@ class BareContact(CommonContact):
                     transport_icon = 'gajim-agent-sms'
                     break
 
+        if self.avatar_sha is not None:
+            transport_icon = None
+
         if pixbuf:
             return app.app.avatar_storage.get_pixbuf(
                 self,
@@ -490,6 +494,17 @@ class ResourceContact(CommonContact):
 
         return None
 
+    @property
+    def is_phone(self):
+        disco_info = app.storage.cache.get_last_disco_info(self._jid)
+        if disco_info is None:
+            return False
+
+        for identity in disco_info.identities:
+            if identity.type == 'phone':
+                return True
+        return False
+
     @property
     def is_available(self) -> bool:
         return self._presence.available
