@@ -44,6 +44,7 @@ from .const import SettingType
 from .settings import SettingsDialog
 from .settings import SettingsBox
 from .settings import PopoverSetting
+from .util import get_app_window
 from .util import open_window
 
 log = logging.getLogger('gajim.gui.accounts')
@@ -564,7 +565,7 @@ class AccountRow(Gtk.ListBoxRow):
         if (account in app.connections and
                 not app.connections[account].state.is_disconnected):
             # Connecting or connected
-            window = cast(Gtk.Window, self.get_toplevel())
+            window = cast(AccountsWindow, get_app_window('AccountsWindow'))
             ConfirmationDialog(
                 _('Disable Account'),
                 _('Account %s is still connected') % account,
@@ -705,7 +706,7 @@ class GeneralPage(GenericSettingPage):
         GenericSettingPage.__init__(self, account, settings)
 
     def _on_account_name_change(self, *args: Any) -> None:
-        window = cast(AccountsWindow, self.get_toplevel())
+        window = cast(AccountsWindow, get_app_window('AccountsWindow'))
         window.update_account_label(self.account)
 
 
@@ -721,6 +722,7 @@ class PrivacyPage(GenericSettingPage):
 
         history_max_age = {
             -1: _('Forever'),
+            0: _('Until Gajim is Closed'),
             86400: _('1 Day'),
             604800: _('1 Week'),
             2629743: _('1 Month'),
