@@ -213,7 +213,7 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
             account, self.contact)
         self.xml.hbox.pack_start(self._security_label_selector, False, True, 0)
 
-        self.msg_textview = MessageInputTextView()
+        self.msg_textview = MessageInputTextView(self.account, self.contact)
         self.msg_textview.connect('paste-clipboard',
                                   self._on_message_textview_paste_event)
         self.msg_textview.connect('key-press-event',
@@ -286,7 +286,6 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
             ('ping-sent', ged.GUI1, self._nec_ping),
             ('ping-reply', ged.GUI1, self._nec_ping),
             ('ping-error', ged.GUI1, self._nec_ping),
-            ('style-changed', ged.GUI1, self._style_changed),
         ])
 
         # This is basically a very nasty hack to surpass the inability
@@ -390,25 +389,6 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
     def is_groupchat(self) -> bool:
         return self._type.is_groupchat
 
-    def safe_shutdown(self) -> bool:
-        """
-        Called to check if control can be closed without losing data.
-        returns True if control can be closed safely else False
-
-        Derived classes MAY implement this.
-        """
-        return True
-
-    def allow_shutdown(self, method, on_response_yes, on_response_no):
-        """
-        Called to check is a control is allowed to shutdown.
-        If a control is not in a suitable shutdown state this method
-        should call on_response_no, else on_response_yes or
-
-        Derived classes MAY implement this.
-        """
-        on_response_yes(self)
-
     def focus(self) -> None:
         raise NotImplementedError
 
@@ -1166,7 +1146,7 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
                     displaymarking: Optional[Displaymarking] = None,
                     msg_log_id: Optional[int] = None,
                     message_id: Optional[str] = None,
-                    stanza_id: Optional[str]  =None,
+                    stanza_id: Optional[str] = None,
                     additional_data: Optional[AdditionalDataDict] = None
                     ) -> None:
 
@@ -1321,12 +1301,6 @@ class BaseControl(ChatCommandProcessor, CommandTools, EventHelper):
         formatting = menu_item.get_name()
         self.msg_textview.apply_formatting(formatting)
 
-    def _style_changed(self, _event: events.StyleChanged) -> None:
-        self.update_text_tags()
-
-    def update_text_tags(self) -> None:
-        self.conversation_view.update_text_tags()
-
     def set_control_active(self, state: bool) -> None:
         if not self._chat_loaded:
             self.fetch_n_lines_history(self._scrolled_view, True, 20)
