@@ -67,7 +67,6 @@ from gajim.command_system.implementation.hosts import GroupChatCommands
 from gajim.gui.const import ControlType
 from gajim.gui.const import TARGET_TYPE_URI_LIST
 from gajim.gui.dialogs import DialogButton
-from gajim.gui.dialogs import ConfirmationCheckDialog
 from gajim.gui.dialogs import ConfirmationDialog
 from gajim.gui.dataform import DataFormWidget
 from gajim.gui.groupchat_inviter import GroupChatInviter
@@ -122,19 +121,30 @@ class GroupchatControl(BaseControl):
         self.correcting: bool = False
         self.last_sent_msg: Optional[str] = None
 
+        self._groupchat_state = GroupchatState()
+        self._groupchat_state.connect('join-clicked',
+                                      self._on_groupchat_state_join_clicked)
+        self._groupchat_state.connect('abort-clicked',
+                                      self._on_groupchat_state_abort_clicked)
+        self.xml.conv_view_overlay.add_overlay(self._groupchat_state)
+
         self.roster = GroupchatRoster(self.account, self.room_jid, self)
         self.xml.roster_revealer.add(self.roster)
-        self.xml.roster_revealer.set_reveal_child(
-            not app.settings.get('hide_groupchat_occupants_list'))
+
+        show_roster = app.settings.get('hide_groupchat_occupants_list')
+        self.xml.roster_revealer.set_reveal_child(show_roster)
         app.settings.bind_signal(
             'hide_groupchat_occupants_list',
             self.xml.roster_revealer,
             'set_reveal_child')
+        self._set_toggle_roster_button_icon(show_roster)
+        app.settings.connect_signal(
+            'hide_groupchat_occupants_list',
+            self._set_toggle_roster_button_icon)
         self.roster.connect('row-activated', self._on_roster_row_activated)
 
         self.add_actions()
         GLib.idle_add(self.update_actions)
-        self.scale_factor = app.window.get_scale_factor()
 
         if not app.settings.get('hide_groupchat_banner'):
             self.xml.banner_eventbox.set_no_show_all(False)
@@ -192,13 +202,6 @@ class GroupchatControl(BaseControl):
 
         self._set_control_inactive()
 
-        self._groupchat_state = GroupchatState()
-        self._groupchat_state.connect('join-clicked',
-                                      self._on_groupchat_state_join_clicked)
-        self._groupchat_state.connect('abort-clicked',
-                                      self._on_groupchat_state_abort_clicked)
-        self.xml.conv_view_overlay.add_overlay(self._groupchat_state)
-
         # Stack
         self.xml.stack.show_all()
         self.xml.stack.set_visible_child_name('groupchat')
@@ -245,7 +248,6 @@ class GroupchatControl(BaseControl):
 
         if self.contact.is_joined:
             self._set_control_active()
-            self._show_roster()
             self._groupchat_state.set_joined()
 
         elif self.contact.is_not_joined:
@@ -371,7 +373,9 @@ class GroupchatControl(BaseControl):
         transition = Gtk.StackTransitionType.SLIDE_DOWN
         if name == 'groupchat':
             transition = Gtk.StackTransitionType.SLIDE_UP
-            self.msg_textview.grab_focus()
+            active_control = app.window.get_active_control()
+            if active_control == self:
+                self.msg_textview.grab_focus()
         self.xml.stack.set_visible_child_full(name, transition)
 
     def _get_current_page(self) -> str:
@@ -406,13 +410,16 @@ class GroupchatControl(BaseControl):
     def _on_invite_clicked(self, _button: Gtk.Button) -> None:
         invitees = self._invite_box.get_invitees()
         for jid in invitees:
-            self.invite(jid)
+            self.invite(JID.from_string(jid))
         self._show_page('groupchat')
 
-    def invite(self, contact_jid: str) -> None:
-        self._client.get_module('MUC').invite(self.room_jid, contact_jid)
+    def invite(self, invited_jid: JID) -> None:
+        self._client.get_module('MUC').invite(
+            self.contact.jid, invited_jid)
+        invited_contact = self._client.get_module('Contacts').get_contact(
+            invited_jid)
         self.add_info_message(
-            _('%s has been invited to this group chat') % contact_jid)
+            _('%s has been invited to this group chat') % invited_contact.name)
 
     def _on_destroy_room(self, _button: Gtk.Button) -> None:
         self.xml.destroy_reason_entry.grab_focus()
@@ -519,12 +526,17 @@ class GroupchatControl(BaseControl):
             self.room_jid,
             {jid: {'affiliation': affiliation}})
 
-    def _show_roster(self, *args: Any) -> None:
-        show = not self.xml.roster_revealer.get_reveal_child()
-        icon = 'go-next-symbolic' if show else 'go-previous-symbolic'
+    def _set_toggle_roster_button_icon(self,
+                                       show_roster: bool,
+                                       *args: Any) -> None:
+        icon = 'go-next-symbolic' if show_roster else 'go-previous-symbolic'
         self.xml.toggle_roster_image.set_from_icon_name(
             icon, Gtk.IconSize.BUTTON)
 
+    def _show_roster(self, *args: Any) -> None:
+        show = not self.xml.roster_revealer.get_reveal_child()
+        self._set_toggle_roster_button_icon(show)
+
         transition = Gtk.RevealerTransitionType.SLIDE_RIGHT
         if show:
             transition = Gtk.RevealerTransitionType.SLIDE_LEFT
@@ -555,7 +567,8 @@ class GroupchatControl(BaseControl):
         self._update_avatar()
 
     def _update_avatar(self) -> None:
-        surface = self.contact.get_avatar(AvatarSize.CHAT, self.scale_factor)
+        surface = self.contact.get_avatar(
+            AvatarSize.CHAT, app.window.get_scale_factor())
         self.xml.avatar_image.set_from_surface(surface)
 
     def draw_banner_text(self) -> None:
@@ -847,11 +860,13 @@ class GroupchatControl(BaseControl):
         self.add_info_message(message)
 
     def _on_user_status_show_changed(self,
-                                     _contact: GroupchatContact,
+                                     contact: GroupchatContact,
                                      _signal_name: str,
                                      user_contact: GroupchatParticipant,
                                      properties: MessageProperties
                                      ) -> None:
+        if not contact.settings.get('print_status'):
+            return
 
         self.conversation_view.add_user_status(user_contact.name,
                                                user_contact.show.value,
@@ -1179,43 +1194,6 @@ class GroupchatControl(BaseControl):
         super(GroupchatControl, self).shutdown()
         app.check_finalize(self)
 
-    def safe_shutdown(self) -> bool:
-        # whether to ask for confirmation before closing muc
-        if app.settings.get('confirm_close_muc') and self.contact.is_joined:
-            return False
-        return True
-
-    def allow_shutdown(self, _method, on_yes, on_no):
-        # whether to ask for confirmation before closing muc
-        if app.settings.get('confirm_close_muc') and self.contact.is_joined:
-            def on_ok(is_checked: bool) -> None:
-                if is_checked:
-                    # User does not want to be asked again
-                    app.settings.set('confirm_close_muc', False)
-                on_yes(self)
-
-            def on_cancel(is_checked: bool) -> None:
-                if is_checked:
-                    # User does not want to be asked again
-                    app.settings.set('confirm_close_muc', False)
-                on_no(self)
-
-            ConfirmationCheckDialog(
-                _('Leave Group Chat'),
-                _('Are you sure you want to leave this group chat?'),
-                _('If you close this window, you will leave '
-                  '\'%s\'.') % self.contact.name,
-                _('_Do not ask me again'),
-                [DialogButton.make('Cancel',
-                                   callback=on_cancel),
-                 DialogButton.make('Accept',
-                                   text=_('_Leave'),
-                                   callback=on_ok)],
-                transient_for=app.window).show()
-            return
-
-        on_yes(self)
-
     def _close_control(self) -> None:
         app.window.activate_action(
             'remove-chat',
