@@ -15,11 +15,11 @@
 from __future__ import annotations
 
 from typing import Any
-from typing import Optional
+from typing import cast
 from typing import Generator
+from typing import Optional
 
 import logging
-import os
 
 from gi.repository import Gtk
 from gi.repository import Gdk
@@ -33,9 +33,9 @@ from gajim.common import events
 from gajim.common import ged
 from gajim.common.client import Client
 from gajim.common.const import Direction
+from gajim.common.const import Display
 from gajim.common.const import SimpleClientState
 from gajim.common.ged import EventHelper
-from gajim.common.helpers import ask_for_status_message
 from gajim.common.i18n import _
 from gajim.common.modules.bytestream import is_transfer_active
 from gajim.plugins.pluginmanager import PluginManifest
@@ -154,24 +154,50 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             client.connect_signal('state-changed',
                                   self._on_client_state_changed)
 
-    def _prepare_window(self) -> None:
-        if app.settings.get('main_window_skip_taskbar'):
-            self.set_property('skip-taskbar-hint', True)
+    def is_minimized(self) -> bool:
+        if app.is_display(Display.WAYLAND):
+            # There is no way to discover if a window is minimized on wayland
+            return False
 
+        window = self.get_window()
+        assert window is not None
+        return bool(Gdk.WindowState.ICONIFIED & window.get_state())
+
+    def is_withdrawn(self) -> bool:
+        window = self.get_window()
+        assert window is not None
+        return bool(Gdk.WindowState.WITHDRAWN & window.get_state())
+
+    def hide(self) -> None:
+        save_main_window_position()
+        Gtk.ApplicationWindow.hide(self)
+
+    def show(self) -> None:
         restore_main_window_position()
+        self.present_with_time(Gtk.get_current_event_time())
+
+    def minimize(self) -> None:
+        self.iconify()
+
+    def unminimize(self) -> None:
+        self.deiconify()
+        self.present_with_time(Gtk.get_current_event_time())
+
+    def _prepare_window(self) -> None:
         window_width = app.settings.get('mainwin_width')
         window_height = app.settings.get('mainwin_height')
         resize_window(self, window_width, window_height)
+
+        self.set_skip_taskbar_hint(not app.settings.get('show_in_taskbar'))
+
         self.show_all()
 
         show_main_window = app.settings.get('show_main_window_on_startup')
-        if (show_main_window == 'always' or
-                not app.settings.get('show_trayicon')):
-            # Without trayicon, we have to show the main window
-            return
+        if show_main_window == 'never':
+            self.hide()
 
-        if (show_main_window == 'never' or
-                not app.settings.get('last_main_window_visible')):
+        elif (show_main_window == 'last_state' and
+                not app.settings.get('is_window_visible')):
             self.hide()
 
     def _on_account_enabled(self, event: events.AccountEnabled) -> None:
@@ -394,45 +420,52 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
     def _on_window_delete(self,
                           _widget: Gtk.ApplicationWindow,
                           _event: Gdk.Event
-                          ) -> bool:
-        # Main window X button was clicked
-        if app.settings.get('quit_on_main_window_x_button'):
+                          ) -> int:
+
+        action = app.settings.get('action_on_close')
+        if action == 'hide':
+            self.hide()
+            return Gdk.EVENT_STOP
+
+        if action == 'minimize':
+            self.minimize()
+            return Gdk.EVENT_STOP
+
+        if not app.settings.get('confirm_on_window_delete'):
             self.quit()
-        else:
-            if (app.settings.get('allow_hide_roster') or
-                    app.app.systray.is_visible()):
-                save_main_window_position()
-                if (os.name == 'nt' or
-                        app.settings.get('hide_on_main_window_x_button')):
-                    self.hide()
-                else:
-                    self.iconify()
-                return True
+            return Gdk.EVENT_STOP
 
-            def _on_ok(is_checked: bool) -> None:
-                if is_checked:
-                    app.settings.set('quit_on_main_window_x_button', True)
-                self.quit()
+        def _on_ok(is_checked: bool) -> None:
+            if is_checked:
+                app.settings.set('confirm_on_window_delete', False)
+            self.quit()
 
-            ConfirmationCheckDialog(
-                _('Quit Gajim'),
-                _('You are about to quit Gajim'),
-                _('Are you sure you want to quit Gajim?'),
-                _('_Always quit when closing Gajim'),
-                [DialogButton.make('Cancel'),
-                 DialogButton.make('Remove',
-                                   text=_('_Quit'),
-                                   callback=_on_ok)]).show()
-        return True
+        ConfirmationCheckDialog(
+            _('Quit Gajim'),
+            _('You are about to quit Gajim'),
+            _('Are you sure you want to quit Gajim?'),
+            _('_Don’t ask again'),
+            [DialogButton.make('Cancel'),
+             DialogButton.make('Remove',
+                               text=_('_Quit'),
+                               callback=_on_ok)]).show()
+
+        return Gdk.EVENT_STOP
 
     def _on_window_state_changed(self,
                                  window: MainWindow,
                                  event: Gdk.EventWindowState) -> None:
 
-        iconified = bool(Gdk.WindowState.ICONIFIED & event.new_window_state)
-        hidden = bool(Gdk.WindowState.WITHDRAWN & event.new_window_state)
-        visible = not (iconified or hidden)
-        app.settings.set('last_main_window_visible', visible)
+        states = Gdk.WindowState.WITHDRAWN | Gdk.WindowState.ICONIFIED
+        if states & event.changed_mask:
+            is_withdrawn = bool(Gdk.WindowState.WITHDRAWN &
+                                event.new_window_state)
+            is_iconified = bool(Gdk.WindowState.ICONIFIED &
+                                event.new_window_state)
+            log.debug('Window state changed: ICONIFIED: %s, WITHDRAWN: %s',
+                      is_iconified, is_withdrawn)
+
+            app.settings.set('is_window_visible', not is_withdrawn)
 
     def _set_startup_finished(self) -> None:
         self._startup_finished = True
@@ -530,6 +563,24 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         chat_list_stack = self._chat_page.get_chat_list_stack()
         return chat_list_stack.get_chatlist(workspace_id)
 
+    def move_chat_to_new_workspace(self,
+                                   account: str,
+                                   jid: JID
+                                   ) -> None:
+        chat_list_stack = self._chat_page.get_chat_list_stack()
+        current_chatlist = cast(ChatList, chat_list_stack.get_visible_child())
+        type_ = current_chatlist.get_chat_type(account, jid)
+        if type_ is None:
+            return
+        current_chatlist.remove_chat(account, jid)
+
+        workspace_id = app.settings.add_workspace(_('My Workspace'))
+        app.window.add_workspace(workspace_id)
+        new_chatlist = self.get_chat_list(workspace_id)
+        new_chatlist.add_chat(account, jid, type_)
+        chat_list_stack.store_open_chats(current_chatlist.workspace_id)
+        chat_list_stack.store_open_chats(workspace_id)
+
     def _add_group_chat(self,
                         _action: Gio.SimpleAction,
                         param: GLib.Variant) -> None:
@@ -825,13 +876,6 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         self._main_stack.process_event(event)
 
     def quit(self) -> None:
-        accounts = list(app.connections.keys())
-        get_msg = False
-        for acct in accounts:
-            if app.account_is_available(acct):
-                get_msg = True
-                break
-
         save_main_window_position()
         window_width, window_height = self.get_size()
         app.settings.set('mainwin_width', window_width)
@@ -887,49 +931,15 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                 return
             on_continue2(message)
 
-        if get_msg and ask_for_status_message('offline'):
-            print('TODO: Let user choose status message')
-            on_continue('')  # status message here
-        else:
-            on_continue('')
+        on_continue('')
 
     def _on_plugin_updates_available(self,
                                      _repository: PluginRepository,
                                      _signal_name: str,
                                      manifests: list[PluginManifest]) -> None:
-
-        def _open_update(is_checked: bool):
-            if is_checked:
-                app.settings.set('plugins_auto_update', True)
-            app.plugin_repository.download_plugins(manifests)
-
-        plugins_str = '\n'
-        plugins_str += '\n'.join([manifest.name for manifest in manifests])
-        ConfirmationCheckDialog(
-            _('Plugin Updates'),
-            _('Plugin Updates Available'),
-            _('There are updates for your plugins:\n'
-              '<b>%s</b>') % plugins_str,
-            _('Update plugins automatically next time'),
-            [DialogButton.make('Cancel'),
-             DialogButton.make('Accept',
-                               text=_('_Update'),
-                               is_default=True,
-                               callback=_open_update)]).show()
+        self._app_page.add_plugin_update_message(manifests)
 
     def _on_plugin_auto_update_finished(self,
                                         _repository: PluginRepository,
                                         _signal_name: str) -> None:
-
-        def _on_ok(is_checked: bool) -> None:
-            if is_checked:
-                app.settings.set('plugins_notify_after_update', False)
-
-        ConfirmationCheckDialog(
-            _('Plugins Updated'),
-            _('Plugins Updated'),
-            _('Plugin updates have successfully been downloaded.\n'
-              'Updates will be installed next time Gajim is started.'),
-            _('Do not show this message again'),
-            [DialogButton.make('OK',
-                               callback=_on_ok)]).show()
+        self.add_app_message('plugin-updates-finished')
