@@ -19,6 +19,8 @@
 
 from typing import Any
 
+import sys
+
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
@@ -28,7 +30,9 @@ from gi.repository import Pango
 from gajim.common import app
 from gajim.common.styling import process
 from gajim.common.styling import PlainBlock
+from gajim.common.types import ChatContactT
 
+from .chat_action_processor import ChatActionProcessor
 from .util import scroll_to_end
 
 if app.is_installed('GSPELL'):
@@ -48,8 +52,11 @@ class MessageInputTextView(Gtk.TextView):
     """
     A Gtk.Textview for chat message input
     """
-    def __init__(self) -> None:
+    def __init__(self, account: str, contact: ChatContactT) -> None:
         Gtk.TextView.__init__(self)
+        self.account = account
+        self.contact = contact
+
         self.set_border_width(3)
         self.set_accepts_tab(True)
         self.set_editable(True)
@@ -66,6 +73,8 @@ class MessageInputTextView(Gtk.TextView):
         self._undo_list: list[str] = []
         self.undo_pressed: bool = False
 
+        self._chat_action_processor = ChatActionProcessor(self)
+
         self.get_buffer().create_tag('strong', weight=Pango.Weight.BOLD)
         self.get_buffer().create_tag('emphasis', style=Pango.Style.ITALIC)
         self.get_buffer().create_tag('strike', strikethrough=True)
@@ -87,6 +96,8 @@ class MessageInputTextView(Gtk.TextView):
             Gtk.DestDefaults.ALL,
             None,
             Gdk.DragAction.DEFAULT)
+        self._chat_action_processor.destroy()
+        app.check_finalize(self)
 
     def _on_focus_in(self,
                      _widget: Gtk.Widget,
@@ -110,9 +121,19 @@ class MessageInputTextView(Gtk.TextView):
         return False
 
     def _clear_tags(self) -> None:
+        to_remove: list[Gtk.TextTag] = []
+        def _check(tag: Gtk.TextTag) -> None:
+            if tag.get_property('underline-rgba-set') is True:
+                # Don’t remove spell checking underlines
+                return
+            to_remove.append(tag)
+
         buf = self.get_buffer()
         start, end = buf.get_bounds()
-        buf.remove_all_tags(start, end)
+        tag_table = buf.get_tag_table()
+        tag_table.foreach(_check)
+        for tag in to_remove:
+            buf.remove_tag(tag, start, end)
 
     def _on_text_changed(self, buf: Gtk.TextBuffer) -> None:
         text = self.get_text()
@@ -121,7 +142,7 @@ class MessageInputTextView(Gtk.TextView):
 
         self._clear_tags()
 
-        if len(text) > 20000:
+        if len(text) > 10000:
             # Limit message styling processing
             return
 
@@ -222,6 +243,10 @@ class MessageInputTextView(Gtk.TextView):
             buf.get_iter_at_offset(end_offset + 2))
 
     def replace_emojis(self) -> None:
+        if sys.platform != 'darwin':
+            # TODO: Remove if colored emoji rendering works well on MacOS
+            return
+
         theme = app.settings.get('emoticons_theme')
         if not theme or theme == 'font':
             return
