@@ -191,23 +191,42 @@ class WindowBehaviour(PreferenceBox):
             'last_state': _('Restore last state'),
         }
 
+        action_on_close_items = {
+            'hide': _('Hide'),
+            'minimize': _('Minimize'),
+            'quit': _('Quit'),
+        }
+
         settings = [
             Setting(SettingKind.POPOVER,
-                    _('Show Gajim on Startup'),
+                    _('Show on Startup'),
                     SettingType.CONFIG,
                     'show_main_window_on_startup',
                     props={'entries': main_window_on_startup_items},
                     desc=_('Show window when starting Gajim')),
 
-            Setting(SettingKind.SWITCH,
-                    _('Quit Gajim on Close'),
+            Setting(SettingKind.POPOVER,
+                    _('Action on Close'),
                     SettingType.CONFIG,
-                    'quit_on_main_window_x_button',
-                    desc=_('Quit when closing Gajim’s window')),
+                    'action_on_close',
+                    props={'entries': action_on_close_items},
+                    desc=_('Action when closing Gajim’s window')),
+
+            Setting(SettingKind.SWITCH,
+                    _('Show in Taskbar'),
+                    SettingType.CONFIG,
+                    'show_in_taskbar',
+                    desc=_('Show window in the taskbar'),
+                    callback=self._on_show_in_taskbar),
+
         ]
 
         PreferenceBox.__init__(self, settings)
 
+    @staticmethod
+    def _on_show_in_taskbar(value: bool, *args: Any) -> None:
+        app.window.set_skip_taskbar_hint(not value)
+
 
 class Plugins(PreferenceBox):
     def __init__(self, *args: Any) -> None:
@@ -541,16 +560,6 @@ class StatusMessage(PreferenceBox):
                     _('Sign In'),
                     SettingType.CONFIG,
                     'ask_online_status'),
-
-            Setting(SettingKind.SWITCH,
-                    _('Sign Out'),
-                    SettingType.CONFIG,
-                    'ask_offline_status'),
-
-            Setting(SettingKind.SWITCH,
-                    _('Status Change'),
-                    SettingType.CONFIG,
-                    'always_ask_for_status_message'),
         ]
 
         PreferenceBox.__init__(self, settings)
@@ -992,10 +1001,12 @@ class Miscellaneous(PreferenceBox):
                                text=_('_Purge'),
                                callback=_purge)]).show()
 
+
 class Advanced(PreferenceBox):
     def __init__(self, pref_window: Preferences) -> None:
 
         settings = [
+
             Setting(SettingKind.SWITCH,
                     _('Debug Logging'),
                     SettingType.VALUE,
@@ -1003,6 +1014,14 @@ class Advanced(PreferenceBox):
                     props={'button-icon-name': 'folder-symbolic',
                            'button-callback': self._on_open_debug_logs},
                     callback=self._on_debug_logging),
+
+            Setting(SettingKind.SWITCH,
+                    _('D-Bus Interface'),
+                    SettingType.CONFIG,
+                    'remote_control',
+                    desc=_('Allow Gajim to broadcast useful information via '
+                           'D-Bus. It also allows other applications to '
+                           'control Gajim remotely.')),
         ]
 
         PreferenceBox.__init__(self, settings)
