@@ -42,8 +42,6 @@ from gajim.common.ged import EventHelper
 
 from .builder import get_builder
 from .util import get_icon_name
-from .util import save_main_window_position
-from .util import restore_main_window_position
 from .util import open_window
 
 if app.is_installed('APPINDICATOR'):
@@ -188,23 +186,15 @@ class GtkMenuBackend(EventHelper):
         app.settings.set('sounds_on', not widget.get_active())
 
     def _on_toggle_window(self, _widget: Gtk.MenuItem) -> None:
-        # When using Gtk.StatusIcon, app.window will never return True for
-        # 'has-toplevel-focus' while clicking the menu item
-        GLib.idle_add(self._on_activate)
+        self._on_activate()
 
     def _on_activate(self, *args: Any) -> None:
-        if app.window.get_property('has-toplevel-focus'):
-            save_main_window_position()
+        if app.window.is_minimized():
+            app.window.unminimize()
+        if app.window.is_withdrawn():
+            app.window.show()
+        else:
             app.window.hide()
-            return
-
-        if not app.window.get_property('visible'):
-            # Window was minimized
-            restore_main_window_position()
-
-        if not app.settings.get('main_window_skip_taskbar'):
-            app.window.set_property('skip-taskbar-hint', False)
-        app.window.present_with_time(Gtk.get_current_event_time())
 
     @staticmethod
     def _on_preferences(_widget: Gtk.MenuItem) -> None:
@@ -245,7 +235,7 @@ class GtkStatusIcon(GtkMenuBackend):
         self._status_icon.set_visible(True)
 
         if count > 0:
-            self._status_icon.set_from_icon_name('dcraven-message-new')
+            self._status_icon.set_from_icon_name('mail-message-new')
             return
 
         show = get_global_show()
@@ -324,7 +314,7 @@ class AppIndicator(GtkMenuBackend):
         self._status_icon.set_status(appindicator.IndicatorStatus.ACTIVE)
 
         if count > 0:
-            icon_name = 'dcraven-message-new'
+            icon_name = 'mail-message-new'
             self._status_icon.set_icon_full(icon_name, _('Pending Event'))
             return
 
